UrlCheckResult class

Result of a Huawei SafetyDetect URL check.

Constructors

UrlCheckResult({required bool success, List<UrlThreatType> threats = const [], String? error, String? errorCode})
Creates a UrlCheckResult.
const
UrlCheckResult.fromMap(Map<String, dynamic> map)
Builds a UrlCheckResult from a platform-channel map.
factory

Properties

error String?
Error message if success is false.
final
errorCode String?
Native error code if success is false.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
true if the request finished successfully (regardless of whether threats were found).
final
threats List<UrlThreatType>
List of threats detected for the requested URL.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited