methodChannel property
The method channel used to talk to the native side.
Implementation
@visibleForTesting
final MethodChannel methodChannel = const MethodChannel('device_integrity');
The method channel used to talk to the native side.
@visibleForTesting
final MethodChannel methodChannel = const MethodChannel('device_integrity');