device_integrity_platform_interface library

Platform interface for the device_integrity plugin.

Plugin implementations (such as MethodChannelDeviceIntegrity) should extend this class rather than implement it, so that newly added methods are not breaking changes for existing implementations.

Classes

DeviceIntegrityPlatform
The interface that platform implementations of device_integrity must implement.
IntegrityResult
Generic result for an integrity / attestation request.
MaliciousApp
Description of a malicious app reported by Huawei SafetyDetect.
UrlCheckResult
Result of a Huawei SafetyDetect URL check.
UserDetectResult
Result of a Huawei SafetyDetect user-detect (reCAPTCHA-style) request.
WifiDetectResult
Result of a Huawei SafetyDetect Wi-Fi detect request.

Enums

UrlThreatType
Threat type returned by Huawei SafetyDetect URL check.