IntegrityResult class
Generic result for an integrity / attestation request.
This is used by:
- Google Play Integrity (classic and standard requests)
- Huawei SafetyDetect SysIntegrity
- Apple DeviceCheck
- Apple App Attest (attestation / assertion)
Constructors
-
IntegrityResult({required bool success, String? token, Map<
String, dynamic> ? metadata, String? error, String? errorCode}) -
Creates an IntegrityResult.
const
-
IntegrityResult.fromMap(Map<
String, dynamic> map) -
Builds an IntegrityResult from a platform-channel map.
factory
Properties
- error → String?
-
Human-readable error message if success is
false.final - errorCode → String?
-
Native error code / exception class name if success is
false.final - hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<
String, dynamic> ? -
Optional extra metadata returned by the platform (for example the
keyIdproduced by App Attest'sgenerateKey).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
trueif the native API returned a token successfully.final - token → String?
-
The opaque token returned by the native API.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited