MaliciousApp class
Description of a malicious app reported by Huawei SafetyDetect.
Constructors
- MaliciousApp({required String packageName, String? apkSha256, int? category})
-
Creates a MaliciousApp.
const
-
MaliciousApp.fromMap(Map<
String, dynamic> map) -
Builds a MaliciousApp from a platform-channel map.
factory
Properties
- apkSha256 → String?
-
SHA-256 of the APK.
final
- category → int?
-
Category code (see Huawei docs).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- packageName → String
-
Package name of the malicious app.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited