UserDetectResult class
Result of a Huawei SafetyDetect user-detect (reCAPTCHA-style) request.
Constructors
- UserDetectResult({required bool success, String? responseToken, String? error, String? errorCode})
-
Creates a UserDetectResult.
const
-
UserDetectResult.fromMap(Map<
String, dynamic> map) -
Builds a UserDetectResult from a platform-channel map.
factory
Properties
- error → String?
-
Error message if success is
false.final - errorCode → String?
-
Native error code if success is
false.final - hashCode → int
-
The hash code for this object.
no setterinherited
- responseToken → String?
-
Response token that must be verified server-side.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
trueif the user passed verification.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited