MethodChannelDeviceIntegrity class
An implementation of DeviceIntegrityPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- DeviceIntegrityPlatform
- MethodChannelDeviceIntegrity
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to talk to the native side.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
appAttestAttestKey(
{required String keyId, required String clientDataHash}) → Future< IntegrityResult> -
Produces an attestation object for the given key.
override
-
appAttestGenerateAssertion(
{required String keyId, required String clientDataHash}) → Future< IntegrityResult> -
Produces an assertion for the given (already attested) key.
override
-
appAttestGenerateKey(
) → Future< IntegrityResult> -
Generates a new App Attest hardware-backed key. Returns the
keyIdin IntegrityResult.token.override -
deviceCheckToken(
) → Future< IntegrityResult> -
Generates a DeviceCheck token (
DCDevice.generateToken).override -
huaweiEnableAppsCheck(
) → Future< bool> -
Enables Huawei SafetyDetect AppsCheck (must be called before
huaweiGetMaliciousAppsList).
override
-
huaweiGetMaliciousAppsList(
) → Future< List< MaliciousApp> > -
Returns the list of malicious apps reported by SafetyDetect AppsCheck.
override
-
huaweiIsVerifyAppsCheck(
) → Future< bool> -
Returns whether Huawei SafetyDetect AppsCheck is currently enabled.
override
-
huaweiSysIntegrity(
{String? nonce, required String appId}) → Future< IntegrityResult> -
Huawei SafetyDetect SysIntegrity check.
override
-
huaweiUrlCheck(
{required String url, required String appId, List< int> ? threatTypes}) → Future<UrlCheckResult> -
Huawei SafetyDetect URL check.
override
-
huaweiUserDetect(
{required String appId}) → Future< UserDetectResult> -
Huawei SafetyDetect User Detect (reCAPTCHA-style).
override
-
huaweiWifiDetect(
) → Future< WifiDetectResult> -
Huawei SafetyDetect Wi-Fi Detect.
override
-
isAppAttestSupported(
) → Future< bool> -
Returns
truewhen Apple App Attest is supported on this device (iOS 14+ on devices with the Secure Enclave).override -
isDeviceCheckSupported(
) → Future< bool> -
Returns
truewhen AppleDCDeviceis supported on this device.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
playIntegrityStandardToken(
{String? requestHash}) → Future< IntegrityResult> -
Requests a Google Play standard Integrity token. You must call
prepareStandardIntegrityToken beforehand.
override
-
playIntegrityToken(
{String? nonce, String? cloudProjectNumber}) → Future< IntegrityResult> -
Requests a Google Play classic Integrity token.
override
-
prepareStandardIntegrityToken(
{required String cloudProjectNumber}) → Future< void> -
Warms up Play Integrity's standard API token provider. Must be
called at least once (ideally well in advance of the request) before
calling playIntegrityStandardToken.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited