DeviceIntegrityPlatform class abstract
The interface that platform implementations of device_integrity must
implement.
- Inheritance
-
- Object
- PlatformInterface
- DeviceIntegrityPlatform
- Implementers
Constructors
- DeviceIntegrityPlatform()
- Constructs a DeviceIntegrityPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
appAttestAttestKey(
{required String keyId, required String clientDataHash}) → Future< IntegrityResult> - Produces an attestation object for the given key.
-
appAttestGenerateAssertion(
{required String keyId, required String clientDataHash}) → Future< IntegrityResult> - Produces an assertion for the given (already attested) key.
-
appAttestGenerateKey(
) → Future< IntegrityResult> -
Generates a new App Attest hardware-backed key. Returns the
keyIdin IntegrityResult.token. -
deviceCheckToken(
) → Future< IntegrityResult> -
Generates a DeviceCheck token (
DCDevice.generateToken). -
huaweiEnableAppsCheck(
) → Future< bool> - Enables Huawei SafetyDetect AppsCheck (must be called before huaweiGetMaliciousAppsList).
-
huaweiGetMaliciousAppsList(
) → Future< List< MaliciousApp> > - Returns the list of malicious apps reported by SafetyDetect AppsCheck.
-
huaweiIsVerifyAppsCheck(
) → Future< bool> - Returns whether Huawei SafetyDetect AppsCheck is currently enabled.
-
huaweiSysIntegrity(
{String? nonce, required String appId}) → Future< IntegrityResult> - Huawei SafetyDetect SysIntegrity check.
-
huaweiUrlCheck(
{required String url, required String appId, List< int> ? threatTypes}) → Future<UrlCheckResult> - Huawei SafetyDetect URL check.
-
huaweiUserDetect(
{required String appId}) → Future< UserDetectResult> - Huawei SafetyDetect User Detect (reCAPTCHA-style).
-
huaweiWifiDetect(
) → Future< WifiDetectResult> - Huawei SafetyDetect Wi-Fi Detect.
-
isAppAttestSupported(
) → Future< bool> -
Returns
truewhen Apple App Attest is supported on this device (iOS 14+ on devices with the Secure Enclave). -
isDeviceCheckSupported(
) → Future< bool> -
Returns
truewhen AppleDCDeviceis supported on this device. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
playIntegrityStandardToken(
{String? requestHash}) → Future< IntegrityResult> - Requests a Google Play standard Integrity token. You must call prepareStandardIntegrityToken beforehand.
-
playIntegrityToken(
{String? nonce, String? cloudProjectNumber}) → Future< IntegrityResult> - Requests a Google Play classic Integrity token.
-
prepareStandardIntegrityToken(
{required String cloudProjectNumber}) → Future< void> - Warms up Play Integrity's standard API token provider. Must be called at least once (ideally well in advance of the request) before calling playIntegrityStandardToken.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ DeviceIntegrityPlatform
-
The default instance of DeviceIntegrityPlatform.
getter/setter pair